package com.demo.whousemywifi.speedtest;

import android.content.ContentValues;
import android.content.Context;
import android.database.Cursor;
import android.database.sqlite.SQLiteDatabase;
import android.database.sqlite.SQLiteException;
import android.database.sqlite.SQLiteOpenHelper;
import android.util.Log;
import java.net.MalformedURLException;
import java.net.URL;
import org.w3c.dom.Element;


public class ServerDbHelper {
    public static final int CC_CLINT = 7;
    public static final String CC_CLSTR = "cc";
    public static final int COUNTRY_CLINT = 6;
    public static final String COUNTRY_CLSTR = "country";
    public static final String DB_NAME = "server.db";
    public static final String DB_TABLE = "server_list";
    public static final int DB_VERSION = 1;
    public static final int HOST_CLINT = 2;
    public static final String HOST_CLSTR = "host";
    public static final int ID_CLINT = 0;
    public static final String ID_CLSTR = "_id";
    public static final int LAT_CLINT = 3;
    public static final String LAT_CLSTR = "latitude";
    public static final int LON_CLINT = 4;
    public static final String LON_CLSTR = "longitude";
    public static final int SPONSOR_CLINT = 5;
    public static final String SPONSOR_CLSTR = "sponsor";
    public static final int URL_CLINT = 1;
    public static final String URL_CLSTR = "url";
    private final Context context;
    private SQLiteDatabase db;
    private serverDBOpenHelper dbHelper;

    
    
    public static class serverDBOpenHelper extends SQLiteOpenHelper {
        private static final String DB_CREATE = "create table server_list (_id integer primary key autoincrement, url text not null, host text not null, latitude text not null, longitude text not null, sponsor text not null, country text not null, cc text not null );";

        public serverDBOpenHelper(Context context, String str, SQLiteDatabase.CursorFactory cursorFactory, int i) {
            super(context, str, cursorFactory, i);
        }

        @Override 
        public void onCreate(SQLiteDatabase sQLiteDatabase) {
            sQLiteDatabase.execSQL(DB_CREATE);
        }

        @Override 
        public void onUpgrade(SQLiteDatabase sQLiteDatabase, int i, int i2) {
            Log.w("TaskDBAdapter", "Upgrading from version " + i + " to " + i2 + ", which will destroy all old data");
            sQLiteDatabase.execSQL("DROP TABLE IF EXISTS server_list");
            onCreate(sQLiteDatabase);
        }
    }

    public ServerDbHelper(Context context) {
        this.context = context;
        this.dbHelper = new serverDBOpenHelper(context, DB_NAME, null, 1);
    }

    public void close() {
        this.db.close();
    }

    public void open() throws SQLiteException {
        try {
            this.db = this.dbHelper.getWritableDatabase();
            Log.w("OPEN DB: ", "WRITEABLE DB CREATED");
        } catch (SQLiteException unused) {
            Log.w("OPEN DB: ", "READABLE DB CREATED");
            this.db = this.dbHelper.getReadableDatabase();
        }
    }

    public long insertServer(Object obj) {
        URL url;
        Element element = (Element) obj;
        String nodeValue = element.getAttributes().getNamedItem("url").getNodeValue();
        try {
            url = new URL(nodeValue);
        } catch (MalformedURLException e) {
            e.printStackTrace();
            url = null;
        }
        String host = url.getHost();
        String nodeValue2 = element.getAttributes().getNamedItem("lat").getNodeValue();
        String nodeValue3 = element.getAttributes().getNamedItem("lon").getNodeValue();
        String nodeValue4 = element.getAttributes().getNamedItem(SPONSOR_CLSTR).getNodeValue();
        String nodeValue5 = element.getAttributes().getNamedItem(COUNTRY_CLSTR).getNodeValue();
        String nodeValue6 = element.getAttributes().getNamedItem(CC_CLSTR).getNodeValue();
        open();
        ContentValues contentValues = new ContentValues();
        contentValues.put("url", nodeValue);
        contentValues.put(HOST_CLSTR, host);
        contentValues.put(LAT_CLSTR, nodeValue2);
        contentValues.put(LON_CLSTR, nodeValue3);
        contentValues.put(SPONSOR_CLSTR, nodeValue4);
        contentValues.put(COUNTRY_CLSTR, nodeValue5);
        contentValues.put(CC_CLSTR, nodeValue6);
        long insert = this.db.insert(DB_TABLE, null, contentValues);
        Log.w("INSERT TASK", "Inserted " + insert + obj.toString());
        close();
        return insert;
    }

    public Cursor getAllCursor() {
        return this.db.query(DB_TABLE, new String[]{ID_CLSTR, "url", HOST_CLSTR, LAT_CLSTR, LON_CLSTR, SPONSOR_CLSTR, COUNTRY_CLSTR, CC_CLSTR}, null, null, null, null, null, null);
    }

    public String retrieveByCountry(String str) {
        SQLiteDatabase sQLiteDatabase = this.db;
        String[] strArr = {ID_CLSTR, "url", HOST_CLSTR, LAT_CLSTR, LON_CLSTR, SPONSOR_CLSTR, COUNTRY_CLSTR, CC_CLSTR};
        Cursor query = sQLiteDatabase.query(DB_TABLE, strArr, "country=" + str, null, null, null, null);
        return query.moveToFirst() ? query.getString(2) : "";
    }
}
