package com.demo.whousemywifi.whousewifi;

import android.content.Context;
import android.os.Build;
import android.os.Handler;
import android.os.Looper;

import java.net.InetAddress;
import java.util.ArrayList;
import java.util.List;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;
import java.util.concurrent.TimeUnit;
import com.demo.whousemywifi.whousewifi.interfaces.OnDeviceFoundListener;
import com.demo.whousemywifi.whousewifi.macinfo.MacAddressInfo;
import com.demo.whousemywifi.whousewifi.models.DeviceItem;


public class DeviceFinder {
    public static final int ERROR_USER_STOPPED = 0;
    public static final int OTHERS = 3;
    public static final String UNKNOWN = "UnKnown";
    public static final int WIFI_NOT_CONNECTED = 2;
    private final Context context;
    private ExecutorService executorService;
    private final OnDeviceFoundListener onDeviceFoundListener;
    private boolean isRunning = false;
    private int timeout = 1500;
    private boolean stopRequested = false;
    private final List<DeviceItem> reachableDevices = new ArrayList();
    private final Handler handler = new Handler(Looper.getMainLooper());

    public DeviceFinder(Context context, OnDeviceFoundListener onDeviceFoundListener) {
        this.context = context;
        this.onDeviceFoundListener = onDeviceFoundListener;
    }

    public DeviceFinder setTimeout(int i) {
        this.timeout = i;
        return this;
    }

    public void start() {
        this.isRunning = true;
        this.stopRequested = false;
        this.reachableDevices.clear();
        new Thread(new Runnable() { 


            @Override 
            public final void run() {
                DeviceFinder.this.startPing();
            }
        }).start();
    }

    public boolean isRunning() {
        return this.isRunning;
    }

    public void stop() {
        this.stopRequested = true;
        this.executorService.shutdownNow();
        if (this.isRunning) {
            sendFailedEvent(0);
        }
        this.isRunning = false;
    }

    private void sendStartEvent() {
        this.handler.post(new Runnable() { 


            @Override 
            public final void run() {
                DeviceFinder.this.m1659x837a18c1();
            }
        });
    }

    
    public  void m1659x837a18c1() {
        this.onDeviceFoundListener.onStart(this);
    }

    private void sendFailedEvent(final int i) {
        this.handler.post(new Runnable() { 
            @Override 
            public final void run() {
                DeviceFinder.this.m1657x736b20a5(i);
            }
        });
    }

    
    public  void m1657x736b20a5(int i) {
        this.onDeviceFoundListener.onFailed(this, i);
    }

    private void sendFinishedEvent(final List<DeviceItem> list) {
        this.handler.post(new Runnable() { 
            @Override 
            public final void run() {
                DeviceFinder.this.m1658x89c945b9(list);
            }
        });
    }

    
    public  void m1658x89c945b9(List list) {
        this.onDeviceFoundListener.onFinished(this, list);
    }

    private static boolean isBelowAndroidR() {
        return Build.VERSION.SDK_INT < 30;
    }

    public void startPing() {
        if (!NetworkInfo.isWifiConnected(this.context)) {
            this.isRunning = false;
            sendFailedEvent(2);
            return;
        }
        this.executorService = Executors.newFixedThreadPool(255);
        sendStartEvent();
        String gatewayAddress = NetworkInfo.getGatewayAddress(this.context);
        String substring = gatewayAddress.substring(0, gatewayAddress.lastIndexOf(".") + 1);
        int i = 0;
        while (i < 255) {
            try {
                StringBuilder sb = new StringBuilder();
                sb.append(substring);
                i++;
                sb.append(i);
                this.executorService.execute(new Ping(sb.toString()));
            } catch (Exception e) {
                e.printStackTrace();
                if (this.stopRequested) {
                    sendFailedEvent(0);
                    return;
                } else {
                    sendFailedEvent(3);
                    return;
                }
            }
        }
        this.executorService.shutdown();
        try {
            if (this.executorService.awaitTermination(10L, TimeUnit.MINUTES)) {
                if (isBelowAndroidR()) {
                    MacAddressInfo.setMacAddress(this.context, this.reachableDevices);
                }
                sendFinishedEvent(this.reachableDevices);
            } else {
                sendFailedEvent(3);
            }
        } catch (InterruptedException e2) {
            if (this.stopRequested) {
                sendFailedEvent(0);
            } else {
                sendFailedEvent(3);
            }
            e2.printStackTrace();
        }
        this.isRunning = false;
    }

    
    public class Ping implements Runnable {
        private final String ipAddress;

        public Ping(String str) {
            this.ipAddress = str;
        }

        @Override 
        public void run() {
            try {
                InetAddress byName = InetAddress.getByName(this.ipAddress);
                if (!Thread.currentThread().isInterrupted() && byName.isReachable(DeviceFinder.this.timeout)) {
                    DeviceItem deviceItem = new DeviceItem();
                    deviceItem.setIpAddress(this.ipAddress);
                    deviceItem.setDeviceName(byName.getHostName());
                    DeviceFinder.this.reachableDevices.add(deviceItem);
                }
            } catch (Exception e) {
                e.printStackTrace();
            }
        }
    }
}
